@@ -11,10 +11,10 @@
 ### Vincent Goulet <vincent.goulet@act.ulaval.ca>
 
 mgamma <- function(order, shape, rate = 1, scale = 1/rate)
-    .External("do_dpq", "mgamma", order, shape, scale, FALSE)
+    .External("actuar_do_dpq", "mgamma", order, shape, scale, FALSE)
 
 levgamma <- function(limit, shape, rate = 1, scale = 1/rate, order = 1)
-    .External("do_dpq", "levgamma", limit, shape, scale, order, FALSE)
+    .External("actuar_do_dpq", "levgamma", limit, shape, scale, order, FALSE)
 
 mgfgamma <- function(x, shape, rate = 1, scale = 1/rate, log = FALSE)
-    .External("do_dpq", "mgfgamma", x, shape, scale, log)
+    .External("actuar_do_dpq", "mgfgamma", x, shape, scale, log)
